@@ -10,4 +10,4 @@ def get_cookie_domain(request):
         return '.stitchdesignlab.com'
 
 def get_assets_v2_domain(request):
-    return 'assets-v2' + get_cookie_domain(request)
+    return '*' + get_cookie_domain(request)
