@@ -1,5 +1,5 @@
 from django.urls import path, include
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from rest_framework.decorators import (
     api_view,
     permission_classes,
@@ -16,6 +16,7 @@ from django.http import HttpResponseRedirect, HttpResponse, HttpResponseBadReque
 
 import logging
 logger = logging.getLogger(__name__)
+User = get_user_model()
 
 
 def include_auth_urls():
